"use strict";

var _react = _interopRequireDefault(require("react"));

var _TourTooltip = _interopRequireDefault(require("../TourTooltip"));

var _enzyme = require("enzyme");

var _Checkbox = _interopRequireDefault(require("../Checkbox"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('TourTooltip', function () {
  describe('default configuration', function () {
    var description = "This is the tooltip's description.";
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_TourTooltip.default, {
      onNext: function onNext() {
        return alert('next');
      },
      onClose: function onClose() {
        return alert('close');
      },
      onPrev: function onPrev() {
        return alert('prev');
      },
      description: description
    }));
    it('renders the tooltip as expected', function () {
      expect(wrapper.children.length).toEqual(1);
    });
    it('contains a checkbox by default', function () {
      expect(wrapper.find(_Checkbox.default).length).toEqual(1);
    });
    it('contains three buttons by default', function () {
      expect(wrapper.find('button').length).toEqual(3);
    });
    it('contains the description text', function () {
      var descRegExp = new RegExp(description);
      expect(descRegExp.test(wrapper.text())).toEqual(true);
    });
  });
  describe('hide functionality options', function () {
    var description = "This is the tooltip's description.";
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_TourTooltip.default, {
      onNext: function onNext() {
        return alert('next');
      },
      onClose: function onClose() {
        return alert('close');
      },
      onPrev: function onPrev() {
        return alert('prev');
      },
      hidePrev: true,
      hideClose: true,
      hideCheckbox: true,
      description: description
    }));
    it('still renders the tooltip', function () {
      expect(wrapper.length).toEqual(1);
    });
    it('only has a single button', function () {
      expect(wrapper.find('button').length).toEqual(1);
    });
    it('does not have a checkbox', function () {
      expect(wrapper.find(_Checkbox.default).length).toEqual(0);
    });
  });
});